==> hadoop-2.10.2-src.tar.gz: hadoop-2.10.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-common/src/test/java/org/apache/hadoop/yarn/webapp/view/TestCommonViews.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.yarn.webapp.view;

import com.google.inject.Injector;

import org.apache.hadoop.yarn.webapp.ResponseInfo;
import org.apache.hadoop.yarn.webapp.test.WebAppTests;
import org.apache.hadoop.yarn.webapp.view.ErrorPage;
import org.apache.hadoop.yarn.webapp.view.FooterBlock;
import org.apache.hadoop.yarn.webapp.view.HeaderBlock;
import org.apache.hadoop.yarn.webapp.view.JQueryUI;

import org.junit.Test;
import static org.mockito.Mockito.*;

public class TestCommonViews {

  @Test public void testErrorPage() {
    Injector injector = WebAppTests.testPage(ErrorPage.class);

  }

  @Test public void testHeaderBlock() {
    WebAppTests.testBlock(HeaderBlock.class);
  }

  @Test public void testFooterBlock() {
    WebAppTests.testBlock(FooterBlock.class);
  }

  @Test public void testJQueryUI() {
    WebAppTests.testBlock(JQueryUI.class);
  }

  @Test public void testInfoBlock() {
    Injector injector = WebAppTests.createMockInjector(this);
    ResponseInfo info = injector.getInstance(ResponseInfo.class);
  }
}

==> hadoop-3.4.2-src.tar.gz: hadoop-3.4.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-common/src/test/java/org/apache/hadoop/yarn/webapp/view/TestCommonViews.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.yarn.webapp.view;

import com.google.inject.Injector;
import org.junit.jupiter.api.Test;

import org.apache.hadoop.yarn.webapp.ResponseInfo;
import org.apache.hadoop.yarn.webapp.test.WebAppTests;

public class TestCommonViews {

  @Test
  void testErrorPage() {
    Injector injector = WebAppTests.testPage(ErrorPage.class);

  }

  @Test
  void testHeaderBlock() {
    WebAppTests.testBlock(HeaderBlock.class);
  }

  @Test
  void testFooterBlock() {
    WebAppTests.testBlock(FooterBlock.class);
  }

  @Test
  void testJQueryUI() {
    WebAppTests.testBlock(JQueryUI.class);
  }

  @Test
  void testInfoBlock() {
    Injector injector = WebAppTests.createMockInjector(this);
    ResponseInfo info = injector.getInstance(ResponseInfo.class);
  }
}
